import { Type } from '../../common/index';
import { Module } from '../module';
import { ModuleConfig } from './module-config';
/**
 * 模块配置构造器
 */
declare class ModuleConfigBuilder {
    /**
     * 构造模块配置
     */
    build(moduleType: Type<Module>): ModuleConfig;
    /**
     * 构造远程实体仓库配置
     */
    private buildRepositoryConfigs;
    /**
     * 构造实体仓库配置
     */
    private buildEntityStoreConfigs;
    /**
     * 构造UI仓库配置
     */
    private buildUIStoreConfigs;
    /**
     * 构造状态机配置
     */
    private buildStateMachineConfigs;
    /**
     * 构造表单仓库配置
     */
    private buildFormStoreConfigs;
    /**
     * 构造表单数组仓库配置
     */
    private buildFormArrayStoreConfigs;
    /**
     * 构造视图模型配置
     */
    private buildViewModelConfigs;
    /**
     * 获取模块元数据
     */
    private getModuleMeta;
    /**
     * 追加Store对应的providers
     * @summary
     * 除了通过注解提供的providers，还需要追加Modlue、Repository、Store对应的Provider，以便静态模式下通过依赖注入创建实例
     */
    private appendModuleProviders;
    /**
     * 创建远程仓库的注入配置
     */
    private createRepositoryProviders;
    /**
     * 创建实体仓库的注入配置
     */
    private createStoreProviders;
}
export { ModuleConfigBuilder };
