import { StaticProvider, Type, TypeDecorator } from '../../common/index';
import { ViewModelState, ViewModel } from '../../viewmodel/index';
import { Repository } from '../../repository/index';
import { Entity, EntityState, EntityStore, UIState, UIStore, FormState, FormStore, FormArrayState, FormArrayStore, StateMachineState, StateMachine } from '../../store/index';
/**
 * 模块元数据名称
 */
declare const MODULE_META_NAME = "MODULE";
/**
 * 模块元数据
 */
interface ModuleMeta {
    id: string;
    deps?: any[];
    providers?: StaticProvider[];
    repositorys?: Type<Repository<Entity>>[];
    entityStores?: Type<EntityStore<EntityState<Entity>>>[];
    uiStores?: Type<UIStore<UIState>>[];
    stateMachines?: Type<StateMachine<StateMachineState>>[];
    formStores?: Type<FormStore<FormState>>[];
    formArrayStores?: Type<FormArrayStore<FormArrayState>>[];
    viewModels?: Type<ViewModel<ViewModelState>>[];
}
/**
 * 模块元数据工厂
 */
declare const moduleMetaFactory: (meta: ModuleMeta) => ModuleMeta;
/**
 * 模块装饰器工厂类型
 */
interface ModuleDecoratorFactory {
    (meta: ModuleMeta): TypeDecorator;
}
/**
 * 模块装饰器工厂类型
 */
declare function FdModule(meta: ModuleMeta): TypeDecorator;
export { MODULE_META_NAME, ModuleMeta, moduleMetaFactory, ModuleDecoratorFactory, FdModule };
