import { Module } from '../../module/index';
import { Store } from '../store/index';
import { ValidationRule } from './validation/index';
import { FormError, FormArrayValue, FormArrayError } from './types';
import { Form } from './form';
import { FormArray } from './form-array';
import { FormArrayState } from './form-state';
import { FormArrayStoreConfig, FormArrayStoreConfigManager } from './configs/index';
/**
 * FormArray仓库
 */
declare class FormArrayStore<S extends FormArrayState> extends Store<S> {
    /**
     * 配置管理器
     */
    private configManager;
    /**
     * 表单状态构造器
     */
    private stateBuilder;
    /**
     * 表单数组
     */
    private formArray;
    /**
      * 构造函数
      */
    constructor(module: Module);
    /**
     * 初始化
     */
    init(config: FormArrayStoreConfig): void;
    /**
     * 初始化FormArray
     */
    initFormArray(formArray: FormArray): void;
    /**
     * 获取FormArray的值
     */
    getValue(): FormArrayValue;
    /**
     * 获取FormArray的错误信息
     */
    getError(): FormArrayError | null;
    /**
     * 获取控件验证规则
     */
    getControlRules(formKey: string, controlName: string): ValidationRule[];
    /**
     * 获取表单数组
     */
    getForms(): Form[];
    /**
     * 向FormArray加载Form
     */
    loadForms(forms: Form[]): void;
    /**
     * 设置控件验证规则
     */
    setControlRules(formKey: string, controlName: string, rules: ValidationRule[]): void;
    /**
     * 校验FormArray
     */
    validate(): FormArrayError | null;
    /**
     * 校验Form
     */
    validateForm(key: string): FormError | null;
    /**
     * 获取配置管理器
     */
    getConfigManager(): FormArrayStoreConfigManager;
    /**
     * 刷新状态
     */
    private refreshState;
    /**
     * 获取最新的状态
     */
    private getLatestState;
}
export { FormArrayStore };
