import { FormError, FormArrayValue, FormArrayError } from './types';
import { ValidationRule } from './validation/index';
import { Form } from './form';
/**
 * 表单数组
 */
declare class FormArray {
    /**
     * 表单数组值
     */
    readonly value: FormArrayValue;
    /**
     * 表单数组校验结果
     */
    readonly valid: boolean;
    /**
     * 表单数组校验错误
     */
    readonly error: FormArrayError | null;
    /**
     * 表单集合
     */
    private forms;
    /**
     * 构造函数
     */
    constructor(forms: Form[]);
    /**
     * 获取Form集合
     */
    getForms(): Form[];
    /**
     * 获取Form
     */
    getForm(formKey: string): Form | null;
    /**
     * 获取控件验证规则
     */
    getControlRules(formKey: string, controlName: string): ValidationRule[];
    /**
     * 加载Form集合
     */
    loadForms(forms: Form[]): void;
    /**
     * 设置控件验证规则
     */
    setControlRules(formKey: string, controlName: string, rules: ValidationRule[]): void;
    /**
     * 校验FormArray
     */
    validate(): FormArrayError | null;
    /**
     * 校验下级Form
     */
    validateForm(formKey: string): FormError | null;
    /**
     * 刷新状态
     */
    refresh(): void;
}
export { FormArray };
