import { Module } from '../../module/index';
import { Store } from '../store/index';
import { FormStoreConfig, FormStoreConfigManager } from './configs/index';
import { ValidationRule, ValidationError } from './validation/index';
import { FormValue, FormError } from './types';
import { Form } from './form';
import { FormState } from './form-state';
/**
 * Form仓库定义
 */
declare class FormStore<S extends FormState> extends Store<S> {
    /**
     * 配置管理器
     */
    configManager: FormStoreConfigManager;
    /**
     * 状态构造器
     */
    private stateBuilder;
    /**
     * 表单实例
     */
    form: Form;
    /**
     * 构造函数
     */
    constructor(module: Module);
    /**
     * 初始化
     */
    init(config: FormStoreConfig): void;
    /**
     * 获取唯一标识
     */
    getKey(): string;
    /**
     * 获取错误值
     */
    getValue(): FormValue;
    /**
     * 获取错误集合
     */
    getError(): FormError | null;
    /**
     * 获取控件验证规则
     */
    getControlRules(name: string): ValidationRule[];
    /**
     * 设置表单唯一标识
     */
    setFormKey(key: string): void;
    /**
     * 设置表单值
     */
    setControlValues(values: FormValue): void;
    /**
     * 设置控件值
     */
    setControlValue(name: string, value: any): void;
    /**
     * 设置控件验证规则
     */
    setControlRules(name: string, rules: ValidationRule[]): void;
    /**
     * 校验整个表单
     */
    validate(): FormError | null;
    /**
     * 校验控件
     */
    validateControl(name: string): ValidationError | null;
    /**
     * 获取配置管理器
     */
    getConfigManager(): FormStoreConfigManager;
    /**
     * 刷新状态
     */
    private refreshState;
    /**
     * 获取最新状态
     */
    private getLatestState;
}
export { FormStore };
