import { FormValue, FormError } from './types';
import { ValidationRule, ValidationError } from './validation';
import { FormControl } from './form-control';
/**
 * Form定义
 */
declare class Form {
    /**
     * 表单索引
     */
    readonly index: number;
    /**
     * 表单唯一标识
     */
    readonly key: string;
    /**
     * 表单值
     */
    readonly value: FormValue;
    /**
     * 校验状态
     */
    readonly valid: boolean;
    /**
     * 校验错误
     */
    readonly error: FormError | null;
    /**
     * 控件集合
     */
    private controls;
    /**
     * 构造函数
     */
    constructor(index: number, key: string, controls: {
        [key: string]: FormControl;
    });
    /**
     * 获取全部控件
     */
    getControls(): {
        [key: string]: FormControl;
    };
    /**
     * 获取单个控件
     */
    getControl(name: string): FormControl | null;
    /**
     * 获取控件值
     */
    getControlValue(name: string): any;
    /**
     * 获取控件验证规则
     */
    getControlRules(name: string): ValidationRule[];
    /**
     * 设置唯一标识
     */
    setKey(key: string): void;
    /**
     * 设置索引
     */
    setIndex(index: number): void;
    /**
     * 批量设置控件值
     */
    setControlValues(values: FormValue): void;
    /**
     * 设置控件值
     */
    setControlValue(name: string, value: any): void;
    /**
     * 设置控件规则
     */
    setControlRules(name: string, rules: ValidationRule[]): void;
    /**
     * 校验表单
     */
    validate(): FormError | null;
    /**
     * 校验单个控件
     */
    validateControl(name: string): ValidationError | null;
    /**
     * 刷新表单
     */
    refresh(): void;
}
export { Form };
