import { EffectManager, Injector } from '../../common/index';
import { Module } from '../../module/index';
import { StoreConfig } from './store-config';
import { StateChange } from './state-change';
/**
 * 状态仓库
 */
declare class Store<S> {
    /**
     * 所属Module
     */
    protected module: Module;
    /**
     * Store配置
     */
    protected config: StoreConfig;
    /**
     * Store状态
     */
    protected state: S;
    /**
     * 副作用管理
     */
    effectManager: EffectManager<StateChange<S>>;
    /**
     * 构造函数
     */
    constructor(module: Module);
    /**
     * 初始化
     */
    init(storeConfig: StoreConfig): void;
    /**
     * 获取ID
     */
    getId(): string;
    /**
     * 获取状态
     */
    getState(): S;
    /**
     * 更新状态
     */
    setState(newState: S): void;
    /**
     * 获取模块
     */
    getModule(): Module;
    /**
     * 获取模块注入器
     */
    getModuleInjector(): Injector;
    /**
     * 触发变更
     */
    triggerChange(change: StateChange<S>): void;
    /**
     * 监听变更
     */
    watchChange(changeEffectFunc: (change: StateChange<S>) => void): Function;
}
export { Store };
